export default {
    "message": "Unexpected token =>",
    "column": 4,
    "index": 9,
    "lineNumber": 2
}